# Watz Python SDK

[![PyPI](https://img.shields.io/pypi/v/watz.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/watz.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/watz)][pypi status]
[![License](https://img.shields.io/pypi/l/watz)][license]

[![Tests](https://github.com/watz-inc/watz-py/workflows/Tests/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/watz-inc/watz-py/branch/main/graph/badge.svg)][codecov]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi status]: https://pypi.org/project/watz/
[license]: https://watz-inc.github.io/watz-py/license
[tests]: https://github.com/watz-inc/watz-py/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/watz-inc/watz-py
[pre-commit]: https://github.com/pre-commit/pre-commit
[black]: https://github.com/psf/black

The Python SDK for Watz APIs.

## Installation

You can install `watz` via [pip](https://pip.pypa.io/) from [PyPI](https://pypi.org/):

```console
$ pip install watz
```

## Usage

Please see the [usage docs](https://watz-inc.github.io/watz-py/usage) for details.

## Getting a key

See the API section on the [Watz website](https://watz.coach/docs/api).

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide](CONTRIBUTING.md).

## License

Distributed under the terms of the [Apache 2.0 license](LICENSE.md), the
_Watz Python SDK_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue](https://github.com/watz-inc/watz-py/issues) along with a detailed description.
